.. -*- coding: utf-8 -*-
.. :Progetto:  SoL
.. :Creato:    gio 06 nov 2008 14:48:21 CET
.. :Autore:    Lele Gaifax <lele@metapensiero.it>
.. :Licenza:   GNU General Public License version 3 or later
..

===========
 Printouts
===========

.. _participants:

Participants
============

.. figure:: participants.png


.. _badges:

Badges
======

.. figure:: finalbadges.png


.. _scoreboards:

Scoreboards
===========

.. figure:: scoreboards.png


.. _results:

Results
=======

.. figure:: results.png


.. _ranking:

Ranking
=======

.. figure:: ranking.png

.. figure:: natranking.png
